@@ -221,3 +221,12 @@ setMethod("trim", "GenomicRanges",
     }
 )
 
+setMethod("trim", "GRangesList",
+          function(x, use.names=TRUE)
+          {
+              ## Like seqinfo,GRangesList, assumes that there is a
+              ## single Seqinfo for the entire object. Only guaranteed
+              ## to be true in the compressed case.
+              relist(trim(unlist(x, use.names=FALSE), use.names=use.names), x)
+          })
+
